{ config, pkgs, ... }:
{
  service = [
    {
      service_description = "Size on /backup2 partition";
      use = "local-service";
      check_command = ["check_local_disk" "10%" "5%" "/backup2"];
    }
    {
      service_description = "Last backup in /backup2/phare is not too old";
      use = "local-service";
      check_command = ["check_last_file_date" "/backup2/phare" "14" "backup"];
    }
    {
      service_description = "Last backup in /backup2/immae_eu is not too old";
      use = "local-service";
      check_command = ["check_last_file_date" "/backup2/immae_eu" "14" "backup"];
    }
    {
      service_description = "Last backup in /backup2/immae_fr is not too old";
      use = "local-service";
      check_command = ["check_last_file_date" "/backup2/immae_fr" "14" "backup"];
    }
    {
      service_description = "Last postgresql dump in /backup2/eldiron/postgresql_backup is not too old";
      use = "local-service";
      check_command = ["check_last_file_date" "/backup2/eldiron/postgresql_backup" "7" "postgres"];
    }
    {
      service_description = "Redis replication for eldiron is up to date";
      use = "local-service";
      check_command = ["check_redis_replication" "/run/redis_eldiron/redis.sock"];
    }
    {
      service_description = "Last redis dump in /backup2/eldiron/redis_backup is not too old";
      use = "local-service";
      check_command = ["check_last_file_date" "/backup2/eldiron/redis_backup" "7" "redis"];
    }
    {
      service_description = "Mysql replication for eldiron is up to date";
      use = "local-service";
      check_command = ["check_mysql_replication" "/run/mysqld_eldiron/mysqld.sock" "/var/secrets/mysql_replication/eldiron/client"];
    }
    {
      service_description = "Last mysql dump in /backup2/eldiron/mysql_backup is not too old";
      use = "local-service";
      check_command = ["check_last_file_date" "/backup2/eldiron/mysql_backup" "7" "mysql"];
    }
    {
      service_description = "Openldap replication for eldiron is up to date";
      use = "local-service";
      check_command = let
        name = "eldiron";
        hcfg = config.myServices.databasesReplication.openldap.hosts.eldiron;
        base = config.myServices.databasesReplication.openldap.base;
        eldiron_schemas = pkgs.callPackage ../databases/openldap/eldiron_schemas.nix {};
        ldapConfig = pkgs.writeText "slapd.conf" ''
          ${eldiron_schemas}
          moduleload  back_hdb
          backend     hdb
          database    hdb

          suffix    "${hcfg.base}"
          directory ${base}/${name}/openldap
          '';
      in [
        "check_openldap_replication"
        hcfg.url
        hcfg.dn
        "${config.secrets.location}/openldap_replication/eldiron/replication_password"
        hcfg.base
        ldapConfig
      ];
    }
    {
      service_description = "Last openldap dump in /backup2/eldiron/openldap_backup is not too old";
      use = "local-service";
      check_command = ["check_last_file_date" "/backup2/eldiron/openldap_backup" "7" "openldap"];
    }
  ];
}
